History
=======

0.1.4 (2017-05-12)

- Tasks can now include external functions
- sound plays by default but can be turned off if parameter sound=False when creating a task.


0.1.3 (2017-04-06)

- Minor bug fixes

0.1.2. (2017-03-19)
-------------------

- Adds sound file

0.1.1 (2017-03-19)
------------------

- Fixes some bugs and now uses pysound

0.1.0 (2017-03-04)
------------------

- First release on PyPI.
